<template>
  <div>
    <el-dialog
      :title="`选择候选部门`"
      :visible.sync="show"
      width="65%"
      :destroy-on-close="true"
      :close-on-click-modal="false"
      :modal="false"
      :before-close="close">
      <el-tree
        ref="tree"
        :data="deptTree"
        show-checkbox
        node-key="id"
        :check-strictly="true"
        :default-expanded-keys="['dept:100']"
        @check-change="handleCheckChange"
        >
      </el-tree>
      <span slot="footer" class="dialog-footer">
        <el-button @click="close">取 消</el-button>
        <el-button type="primary" @click="submit">确 定</el-button>
      </span>
    </el-dialog>
  </div>
</template>

<script>
import {flowableDeptTreeSelect} from "@/api/system/user";

export default {
  name: "index",
  props: {
    show: {
      required: true,
      type: Boolean
    },
    checkeds: {
      required: true
    }
  },
  watch: {
    show: {
      handler(newV) {
        this.$nextTick(() => {
          if (this.$refs.tree && this.checkeds) {
            this.$refs.tree.setCheckedKeys(this.checkeds);
          }
        });
      },
      deep: true
    }
  },
  data() {
    return {
      deptTree: [],
      checkList: [],
    }
  },
  created() {
    flowableDeptTreeSelect().then(res => {
      this.deptTree = res.data
    })
  },
  methods: {
    setCheckList(value) {
      this.checkList = value
      this.$nextTick(() => {
        if (this.$refs.tree && this.checkeds) {
          this.$refs.tree.setCheckedKeys(this.checkeds);
        }
      });
    },
    handleCheckChange(data, checked, indeterminate) {
      if (checked) {
        if (this.checkList.indexOf(data) === -1) {
          this.checkList.push(data)
        }
      } else {
        this.checkList = this.checkList.filter(item => item !== data)
      }
      console.log(data, checked, indeterminate);
    },
    close() {
      this.$emit("close")
    },
    submit() {
      const checkedIds = this.checkList.map(item => item.id).join(",")
      const names = this.checkList.map(item => item.label).join(",")
      this.$emit("submit", checkedIds, names)
    }
  }
}
</script>

<style scoped>

</style>
